@@ -8,7 +8,8 @@ autodoc_mock_imports = [
     'MDAnalysis.analysis',
     'freud',
     'numpy',
-    'scipy'
+    'scipy',
+    'pandas'
 ]
 extensions = [
     'sphinx.ext.autodoc',
@@ -28,7 +29,7 @@ project = 'lipyphilic'
 year = '2021'
 author = 'Paul Smith'
 copyright = '{0}, {1}'.format(year, author)
-version = release = '0.1.0'
+version = release = '0.3.0'
 
 autodoc_typehints = 'signature'
 autodoc_docstring_signature = True
@@ -48,6 +49,7 @@ on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
 if not on_rtd:  # only set the theme if we're building docs locally
     html_theme = 'sphinx_rtd_theme'
 
+html_logo = 'logo/lipyphilic_logo_grey.png'
 html_use_smartypants = True
 html_last_updated_fmt = '%b %d, %Y'
 html_split_index = False
